@@ -7,8 +7,8 @@
 ;; Maintainer:  Russel Winder <russel@winder.org.uk>
 ;;              Vladimir Panteleev <vladimir@thecybershadow.net>
 ;; Created:  March 2007
-;; Package-Version: 2.0.12
-;; Package-Revision: 024aca97d07e
+;; Package-Version: 20241225.1823
+;; Package-Revision: e8754635a7db
 ;; Keywords:  D programming language emacs cc-mode
 ;; Package-Requires: ((emacs "25.1"))
 
@@ -179,6 +179,11 @@
 (c-lang-defconst c-ml-string-max-closer-len
   d 1)
 
+(c-lang-defconst c-string-innards-re-alist
+  ;; Note: the " rule doesn't cover r" literals.
+  d (list (cons ?\" "\\(\\\\\\([^z-a]\\)\\|[^\"\\]\\)*")
+          (cons ?` "\\([^`]\\)*")))
+
 (c-lang-defconst c-opt-cpp-prefix
   ;; Preprocessor directive recognizer.  D doesn't have cpp, but it has #line
   d "\\s *#\\s *")
@@ -225,7 +230,8 @@ operators."
   d '("bool" "byte" "ubyte" "char" "delegate" "double" "float"
       "function" "int" "long" "short" "uint" "ulong" "ushort"
       "cent" "ucent" "real" "ireal" "idouble" "ifloat" "creal" "cfloat" "cdouble"
-      "wchar" "dchar" "void" "string" "wstring" "dstring" "__vector"))
+      "wchar" "dchar" "void" "string" "wstring" "dstring" "__vector"
+      "size_t" "ptrdiff_t" "noreturn"))
 
 ;; Keywords that can prefix normal declarations of identifiers.
 ;; Union of StorageClass, Attribute, and ParameterAttributes in D grammar.
@@ -239,7 +245,8 @@ operators."
       "nothrow" "out" "override" "package" "pragma" "private"
       "protected" "public" "pure" "ref" "return" "scope" "shared"
       "static" "synchronized"
-      "@property" "@safe" "@trusted" "@system" "@nogc" "@disable"))
+      "@property" "@safe" "@trusted" "@system" "@nogc" "@disable"
+      "typeof"))
 
 (c-lang-defconst c-class-decl-kwds
   ;; Keywords introducing declarations where the following block (if any)
@@ -301,7 +308,8 @@ operators."
 (c-lang-defconst c-paren-nontype-kwds
   ;;Keywords that may be followed by a parenthesis expression that doesn't
   ;; contain type identifiers.
-  d '("version" "debug" "extern" "pragma" "__traits" "scope"))
+  d '("version" "debug" "extern" "pragma" "__traits" "scope" "typeof"
+      "align" "package"))
 
 (c-lang-defconst d-type-modifier-kwds
   ;; D's type modifiers.
@@ -532,7 +540,7 @@ Evaluate OLD-FORM if the Emacs version is older than MIN-VERSION,
 
 ;----------------------------------------------------------------------------
 
-(defun d-forward-decl-or-cast-1 (preceding-token-end context last-cast-end)
+(defun d-forward-decl-or-cast-1 (preceding-token-end context last-cast-end &optional inside-macro)
   "D version of `c-forward-decl-or-cast-1'." ;; checkdoc-params: (preceding-token-end context last-cast-end)
   ;; (message "(d-forward-decl-or-cast-1 %S %S %S) @ %S" preceding-token-end context last-cast-end (point))
 
@@ -1611,8 +1619,9 @@ The expression is added to `compilation-error-regexp-alist' and
 	   (lambda (match-pos inside-macro toplev)
 	     (when toplev
 	       (let* ((got-context
-		       (c-get-fontification-context
-			match-pos nil toplev))
+		       (save-excursion
+			 (c-get-fontification-context
+			  match-pos nil toplev)))
 		      (context (car got-context))
 		      (decl-or-cast
 		       (when (eq context 'top)
@@ -1875,9 +1884,6 @@ Key bindings:
    #'d--syntax-propertize-function)
 
   (c-common-init 'd-mode)
-  (d--if-version>= "28"
-      nil
-    (easy-menu-add d-menu))
   (c-run-mode-hooks 'c-mode-common-hook 'd-mode-hook)
   (c-update-modeline)
   (d--if-version>= "26.0"
